@@ -10,9 +10,13 @@ __version__ = '0.0.2'
 import sys
 import argparse
 from typing import Union, List, Dict, Any
+import logging
+
 from morm.db import DB
 from morm.migration import Migration
 
+log = logging.getLogger('morm:admin')
+log.setLevel(logging.INFO)
 
 def init_project():
     files = {
@@ -23,34 +27,39 @@ DB_POOL = Pool(
     dsn='postgres://',
     host='localhost',
     port=5432,
-    user='jahid',
-    password='jahid',
-    database='test',
+    user='user',
+    password='pass',
+    database='db_name',
     min_size=10,
     max_size=90,
 )
             """,
         'mgr.py': """
+import os
 from morm.migration import migration_manager
-from _morm_config_ import DB_POOL                       # change accordingly
-from app.models import SomeModel, SomeOtherModel,   # change accordingly
+from _morm_config_ import DB_POOL
 
-MIGRATION_BASE_PATH = '/some_absolute_path'         # change accordingly
+from app.models import SomeModel, SomeOtherModel        # change accordingly
+
+MIGRATION_BASE_PATH = os.path.realpath('_migrations_')
 
 migration_models = [
-    SomeModel,                                      # change accordingly
-    SomeOtherModel,                                 # change accordingly
+    SomeModel,                                          # change accordingly
+    SomeOtherModel,                                     # change accordingly
 ]
 
 if __name__ == '__main__':
     migration_manager(DB_POOL, MIGRATION_BASE_PATH, migration_models)
-        """
+"""
 
     }
 
     for name, content in files.items():
-        with open(name, 'x', encoding='utf-8') as f:
-            f.write(content)
+        try:
+            with open(name, 'x', encoding='utf-8') as f:
+                f.write(content)
+        except FileExistsError:
+            log.exception(f'Skipping creating file: {name}')
     return files
 
 def main():
