@@ -278,7 +278,7 @@ class DB(object):
         for n,v in new_data_gen:
             c += 1
             if reset:
-                v._value_change_count = 0
+                v.value_change_count = 0
                 mob.Meta._fromdb_ = []
             columns.append(n)
             values.append(v.value)
@@ -318,7 +318,7 @@ class DB(object):
                 colval.append(f'"{n}"=${c}')
                 values.append(v.value)
                 if reset:
-                    v._value_change_count = 0
+                    v.value_change_count = 0
         colval_q = ', '.join(colval)
         if colval_q:
             where = f'"{mob.__class__._get_pk_()}"=${c+1}'
@@ -352,7 +352,10 @@ class DB(object):
             (str): status of last sql command.
         """
         query, args = self.get_delete_query(mob)
-        return await self.execute(query, *args, timeout=timeout)
+        await mob._pre_delete_(self)
+        res = await self.execute(query, *args, timeout=timeout)
+        await mob._post_delete_(self)
+        return res
 
     async def insert(self, mob: ModelBase, timeout: float = None) -> Any:
         """Insert the current data state of mob into db.
@@ -365,9 +368,11 @@ class DB(object):
             (Any): Value of primary key of the inserted row
         """
         query, args = self.get_insert_query(mob, reset=True)
+        await mob._pre_insert_(self)
         pkval = await self.fetchval(query, *args, timeout=timeout)
         if pkval is not None:
             setattr(mob, mob.__class__._get_pk_(), pkval)
+        await mob._post_insert_(self)
         return pkval
 
     async def update(self, mob: ModelBase, timeout: float = None) -> str:
@@ -387,8 +392,12 @@ class DB(object):
         """
         query, args = self.get_update_query(mob, reset=True)
         if query:
-            return await self.execute(query, *args, timeout=timeout)
-        return self.DATA_NO_CHANGE
+            await mob._pre_update_(self)
+            res = await self.execute(query, *args, timeout=timeout)
+            await mob._post_update_(self)
+        else:
+            res = self.DATA_NO_CHANGE
+        return res
 
 
     async def save(self, mob: ModelBase, timeout: float = None) -> Union[str, Any]:
@@ -405,10 +414,13 @@ class DB(object):
             int or str: The value of the primary key for insert or
                             status for update.
         """
+        await mob._pre_save_(self)
         try:
-            return await self.update(mob, timeout=timeout)
+            res = await self.update(mob, timeout=timeout)
         except AttributeError:
-            return await self.insert(mob, timeout=timeout)
+            res = await self.insert(mob, timeout=timeout)
+        await mob._post_save_(self)
+        return res
 
     def q(self, model: ModelType = None) -> 'ModelQuery':
         """Return a ModelQuery for model
@@ -977,6 +989,9 @@ class ModelQuery():
             col = self.model.Meta.pk    #type: ignore
         return await self.reset().qfilter().qc(col, comp, *vals).fetchrow()
 
+SERIALIZABLE = 'serializable'
+REPEATABLE_READ = 'repeatable_read'
+READ_COMMITTED = 'read_committed'
 
 class Transaction():
     """Start a transaction.
@@ -1008,7 +1023,7 @@ class Transaction():
         deferrable (bool, optional): Specifies whether this transaction is deferrable. Defaults to False.
     """
     def __init__(self, pool: Pool, *,
-                isolation: str='read_committed',
+                isolation: str=READ_COMMITTED,
                 readonly: bool=False,
                 deferrable: bool=False):
         self._pool = pool
@@ -1020,17 +1035,17 @@ class Transaction():
             'deferrable': deferrable,
         }
 
-    async def __aenter__(self) -> Connection:
+    async def __aenter__(self) -> DB:
         return await self.start()
 
-    async def start(self) -> Connection:
+    async def start(self) -> DB:
         """Start transaction.
 
         Raises:
             exceptions.TransactionError: When same object is used simultaneously for transaction
 
         Returns:
-            Connection: Connection object.
+            DB: DB object.
         """
         if self.db._con:
             raise exceptions.TransactionError('Another transaction is running (or not ended properly) with this Transaction object')
